


#from distutils.core import setup
from setuptools import setup

setup(name = "printlistmodulepackageneeraj", version="1.0.0", description="an API to print \
      a list recursively", author="Neeraj", author_email="neeraj.pm@ignitarium.com", \
          py_modules=["printlistmodule"])